ジャンプ先: 概要. 戻り値. 関連. フラグ. MEL 例.

概要

boundary [-caching boolean] [-constructionHistory boolean] [-endPoint boolean] [-endPointTolerance linear] [-name string] [-nodeState int] [-object boolean] [-order boolean] [-polygon int] [-range boolean] string string string [string]

boundary は、取り消し可能、照会可能、および編集可能です。

このコマンドは、3 つまたは 4 つのカーブが指定した境界サーフェスを生成します。作成される境界サーフェスは 1 つの方向に指定した 2 つのカーブを通過します。残ったカーブによってシェイプを別の方向に定義します。「endPoint」オプションがオンの場合、カーブの終点はサーフェスが作成される前に接している必要があります。これは、境界サーフェスが便利なケースです。

このコマンドには接線連続性のオプションはないということに注意してください。カーブの終点がすべて接していない限り、作成されるサーフェスはすべてのカーブを通過しません。代わりに、birail コマンドを使用します。

戻り値

string[]オブジェクト名とノード名

照会モードでは、戻り値のタイプは照会されたフラグに基づきます。

関連

doubleProfileBirailSurface, loft, squareSurface

フラグ

caching, constructionHistory, endPoint, endPointTolerance, name, nodeState, object, order, polygon, range
ロング ネーム(ショート ネーム) 引数タイプ プロパティ
-caching(-cch) boolean createqueryedit
すべてのアトリビュートのキャッシングを切り替えることで、再計算を不要にします。
-endPoint(-ep) boolean createqueryedit
true は、サーフェスが作成される前にカーブの終端が接している必要があるという意味です。
既定: false
-endPointTolerance(-ept) linear createqueryedit
endPoint アトリビュートが true の場合のみ使用される、終点の許容値です。
既定: 0.1
-nodeState(-nds) int createqueryedit

Maya のディペンデンシー ノードには 6 種類の設定可能な状態があります。通常(Normal)(0)、エフェクトなし(HasNoEffect)(1)、ブロッキング(Blocking)(2)ステータスは、グラフの評価方法を変更するために使用されます。

待機 - 通常(Waiting-Normal)(3)、待機 - エフェクトなし(Waiting-HasNoEffect)(4)、待機 - ブロッキング(Waiting-Blocking)(5)は、内部でのみ使用されます。これらは、インタラクション(例: 操作)の実行中にグラフのパーツを一時的に遮断します。操作が完了すると、ステータスは適切にリセットされます(例: 待機 - ブロッキング(Waiting-Blocking) は ブロッキング(Blocking) にリセットされます)。

通常(Normal)およびブロッキング(Blocking)のケースはすべてのノードに適用できますが、エフェクトなし(HasNoEffect)はノード特定です。多くのノードはこのオプションをサポートしていません。プラグインは状態を MPxNode::state アトリビュートに保存します。誰もがこのアトリビュートを設定したり確認したりすることができます。これらの 3 つの状態に関するその他の詳細は次の通りです。

状態 説明
通常(Normal) 通常のノードの状態です。これが既定の設定です。
エフェクトなし(HasNoEffect)

エフェクトなし(HasNoEffect)オプション(別名: 通過)は、同じデータ タイプの出力を生成する入力を操作している場合に使用されます。 ほぼすべてのデフォーマが、他のいくつかのノードと同様に、この状態をサポートします。前に説明したように、すべてのノードでサポートされるわけではありません。

ノードの計算メソッドでエフェクトなし(HasNoEffect)状態のサポートを実装し、適切な操作を実行することが一般的です。プラグインはエフェクトなし(HasNoEffect)もサポートします。

この状態を普通に実装するには、ノードにアルゴリズムを適用しないで、適合する出力に直接入力をコピーします。デフォーマの場合は、この状態を適用することにより、入力ジオメトリが出力でデフォーム解除されたままになります。

ブロッキング(Blocking)

これはディペンデンシー ノードのベース クラスで実装され、すべてのノードに適用されます。ブロッキング(Blocking)は評価フェーズ中に接続に適用されます。 ブロックされた接続に対する評価要求が失敗を返すと、目的プラグが現在の値を保持します。 ダーティな伝播はこの状態の間接的な影響を受けますが、ブロックされた接続がクリーンアップされることはありません。

ノードをブロッキング(Blocking)に設定すると、すべての送信接続が解除されたのと同じ動作になる可能性があります。 ブロックされたノードの評価を直接要求しない限り、その後に再評価されることはありません。ブロックされたノードは getAttr 要求に引き続き応答しますが、下流ノードの getAttr は、ブロックされたノードを再評価しないことに注意してください。

ブロッキング(Blocking)に対して階層のルート変換を設定しても、自動的にはこの階層の子変換に影響しません。これを実行するには、ブロッキング(Blocking)状態に対してすべての子ノードを明示的に設定する必要があります。

たとえば、すべての子トランスフォームをブロッキング(Blocking)に設定するには、次のスクリプトを使用します。

 import maya.cmds as cmds def blockTree(root): nodesToBlock = [] for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys(): nodesToBlock += cmds.listConnections(node, source=True, destination=True ) for node in {source:1 for source in nodesToBlock}.keys(): cmds.setAttr( '%s.nodeState' % node, 2 ) 

このスクリプトを適用してオブジェクトの描画を継続できますが、アニメートは行えません。


既定: kdnNormal
-order(-or) boolean createqueryedit
カーブの順序が重要な場合は true です。
既定: true
共通のフラグ
-constructionHistory(-ch) boolean create
コンストラクション ヒストリをオンまたはオフにします。
-name(-n) string create
新しく作成するノードの名前を設定します。ネームスペース パスを含む場合、指定されたネームスペースの下に新しいノードが作成されます。ネームスペースが存在しない場合は、ネームスペースが作成されます。
-object(-o) boolean create
結果のオブジェクト、またはディペンデンシー ノードのみを作成します。
-polygon(-po) int create
この引数の値は、この操作で作成されるオブジェクトのタイプを制御します。
  • 0: NURBS サーフェス
  • 1: ポリゴン(nurbsToPolygonsPref を使用して変換用のパラメータを設定)
  • 2: サブディビジョン サーフェス(nurbsToSubdivPref を使用して変換用のパラメータを設定)
  • 3: ベジェ サーフェス
  • 4: サブディビジョン サーフェス ソリッド(変換のためのパラメータを設定するには、nurbsToSubdivPref を使用)
-range(-rn) boolean create
カーブの範囲を入力カーブ全体に強制します。

フラグはコマンドの作成モードで表示できます フラグはコマンドの編集モードで表示できます
フラグはコマンドの照会モードで表示できます コマンド内でフラグを複数回使用できます。

MEL 例

// Creating boundary surfaces with three curves:

string $crv1 = `curve -d 3 -p 8 0 3 -p 5 0 3 -p 2 0 2 -p 0 0 0 `;
string $crv2 = `curve -d 3 -p 8 0 -4 -p 5 0 -3 -p 2 0 -2 -p 0 0 0 `;
string $crv3 = `curve -d 3 -p 10 0 3 -p 9 3 2 -p 11 3 1 -p 9 0 -3` ;

// These curves form a rough triangle shape pointing at the origin.
// If order is OFF, then the apex of the surface will always between
// the 1st and 2nd curves.

boundary -order off -ep 0 $crv3 $crv1 $crv2;
boundary -order off -ep 0 $crv3 $crv2 $crv1;

// If order is ON, then think of the order of selection as "rail, rail, profile"
// where the boundary is formed by sweeping the profile along two rails.
// Direction of the curves becomes important as well; use the reverseCurve
// command if you want to change a curve's direction.
boundary -order on $crv1 $crv2 $crv3;

// Creating boundary surfaces with four curves:

string $crv1 = `curve -d 3 -p -2 0 5 -p -1 0 3 -p 1 0 3 -p 3 0 4 -p 6 0 5`;
string $crv2 = `curve -d 3 -p 7 0 4 -p 8 0 2 -p 8 0 -3 -p 7 0 -4 `;
string $crv3 = `curve -d 3 -p 6 0 -5 -p 2 0 -3 -p -1 0 -5 -p -3 0 -5`;
string $crv4 = `curve -d 3 -p -2 0 4 -p -4 0 1 -p -4 0 -3 -p -2 0 -4` ;

// These curves form a rough square shape around the origin.
// To make a boundary surface from four curves, two of the curves are
// "rails" while the other two are "profiles".

boundary -order off -ep 0 $crv1 $crv2 $crv3 $crv4;
boundary -order off -ep 0 $crv2 $crv3 $crv4 $crv1;
                                  // profile, rail, profile, rail
// Notice that in both cases, the resulting boundary surface passes through
// the rail curves.

// When order is ON, direction of the curves becomes important;
// use the reverseCurve command if you want to change a curve's direction.
// Notice the difference between:

boundary -order off -ep 0 $crv1 $crv2 $crv3 $crv4;
boundary -order on -ep 0 $crv1 $crv2 $crv3 $crv4;